Meshtastic Monitor

## Status

Open JSON
Loading…

### Overview

### Power

### Memory

### Airtime

### Radio

### WiFi

## Nodes

Short | Long | Role | Device | SNR | Quality | Hops | Last Seen | ID
--- | --- | --- | --- | --- | --- | --- | --- | ---
Loading…

## Channels

—
—
Text
Channel
Pick a channel to send on, or leave Auto.

## Stats

—
Loading…

### Nodes visible (live)

### Messages (hourly)

### Status (latest)

### Battery % (recent)

### Channel Utilization (recent)

### WiFi RSSI (recent)

### Apps

### Requests to Me

### Top From

### Top To

### Recent Events

## My Radio

—
Loading…

### Settings

API Base URL (optional)
Leave blank when using the built-in UI.
Meshtastic IP / Host
Port

### Node Details

—
Loading…

#### Messaging

Text
Channel
Optional: choose a channel for this direct message.